#![feature(new_uninit, once_cell, trait_alias)]

mod bot;
mod cmd;
mod config;
mod utils;

use crate::{bot::Bot, cmd::Cmd};
use log::info;
use matrix_sdk;
use std::env;

static EMOJI_PLUS: &str = "➕";
static EMOJI_MINUS: &str = "➖";

#[tokio::main]
async fn main() -> matrix_sdk::Result<()> {
    config::setup_logging();
    config::check_argument_or_abort(true);

    info!("EMOJI PLUS: {}", EMOJI_PLUS);
    info!("EMOJI MINUX: {}", EMOJI_MINUS);

    let basic_cmds = vec![
        Cmd::new_simple(format!("ping"), 0, |_x| true, None),
        Cmd::new_echo(format!("bot_name"), 0, |_x| format!("toto"), None),
        Cmd::new_echo(
            format!("react"),
            0,
            |_| format!("React to the following"),
            Some(vec![":1".to_string(), ":2".to_string()]),
        ),
    ];

    let mut bot = Bot::new(env::args().last().unwrap());
    Bot::add_package(bot.get_configuration(), format!("basic"), basic_cmds);
    bot.connect().await?.listen().await
}
